@@ -12,8 +12,7 @@ create_beast2_input_data_sequences <- function( # nolint indeed long function na
 
   nucleotides_uppercase <- beauti_options$nucleotides_uppercase
 
-  sequences_table <- fasta_file_to_sequences(
-    input_fasta_filename)
+  sequences_table <- beautier::fasta_file_to_sequences(input_fasta_filename)
   sequences <- as.matrix(cbind(rownames(sequences_table), sequences_table))
   text <- NULL
   for (i in seq(1, nrow(sequences))) {
@@ -21,7 +20,13 @@ create_beast2_input_data_sequences <- function( # nolint indeed long function na
     nextline <- paste0(
       "<sequence id=\"seq_",
       trimws(row[1]),
-      "\" taxon=\"",
+      "\" "
+    )
+    if (beauti_options$beast2_version == "2.6") {
+      nextline <- paste0(nextline, "spec=\"Sequence\" ")
+    }
+    nextline <- paste0(nextline,
+      "taxon=\"",
       trimws(row[1]),
       "\" totalcount=\"4\" value=\"",
       ifelse(nucleotides_uppercase == TRUE, toupper(row[2]), row[2]),
@@ -30,5 +35,18 @@ create_beast2_input_data_sequences <- function( # nolint indeed long function na
     text <- c(text, nextline)
   }
   text <- sort(text, method = "radix")
+
+  if (beauti_options$beast2_version == "2.6") {
+    text <- beautier::interspace(text)
+    text <- stringr::str_replace_all(
+      string = text,
+      pattern = "$^",
+      replacement = paste0(
+        rep(" ", 20),
+        collapse = ""
+      )
+    )
+  }
+
   beautier::indent(text = text, n_spaces = beauti_options$sequence_indent)
 }
