@@ -1,8 +1,5 @@
 #' General function to create a parameter.
-#' @param name the parameters' name. Valid
-#'   names can be found in \code{\link{get_param_names}}
-#' @param id the parameter's ID
-#' @param ... specific parameter parameters
+#' @inheritParams default_parameters_doc
 #' @note Prefer using the
 #'   named functions
 #'   \code{\link{create_alpha_param}},
@@ -24,7 +21,7 @@
 #'   \code{\link{create_scale_param}},
 #'   and \code{\link{create_sigma_param}}
 #' @return a parameter
-#' @author Richel J.C. Bilderbeek
+#' @author Richèl J.C. Bilderbeek
 #' @examples
 #'   # Create an alpha parameter
 #'   alpha_param <- create_alpha_param()
@@ -35,18 +32,20 @@
 #'   )
 #'
 #'   # Use the distribution to create a BEAST2 input file
+#'   beast2_input_file <- tempfile(fileext = ".xml")
 #'   create_beast2_input_file(
-#'     input_filenames = get_fasta_filename(),
-#'     "create_alpha_param.xml",
-#'     tree_priors = create_yule_tree_prior(
+#'     input_filename = get_fasta_filename(),
+#'     beast2_input_file,
+#'     tree_prior = create_yule_tree_prior(
 #'       birth_rate_distr = beta_distr
 #'     )
 #'   )
-#'   testit::assert(file.exists("create_alpha_param.xml"))
+#'   testit::assert(file.exists(beast2_input_file))
 #' @export
 create_param <- function(
   name,
   id,
+  value,
   ...
 ) {
   if (!is_param_name(name)) {
@@ -66,26 +65,25 @@ create_param <- function(
   parameter <- list(
     name = name,
     id = id,
+    value = value,
     ...
   )
   parameter
 }
 
 #' Create a parameter called alpha
-#' @inheritParams create_param
-#' @param estimate TRUE if this parameter alpha be estimated by BEAST2,
-#'   FALSE otherwise
-#' @param value value of the parameter
+#' @inheritParams default_parameters_doc
 #' @return a parameter called alpha
 #' @note this parameter is used in a beta distribution
 #'   (as returned by \code{\link{create_beta_distr}})
 #' and gamma distribution
 #'   (as returned by \code{\link{create_gamma_distr}})
-#' and inverse gamma distribution
-#'   (as returned by \code{\link{create_inv_gamma_distr}})
+#' and inverse-gamma distribution
+#'   (as returned by \code{\link{create_inv_gamma_distr}}).
+#' It cannot be estimated (as a hyper parameter) yet.
 #' @seealso the function \code{\link{create_param}} contains a list
 #'   of all parameters that can be created
-#' @author Richel J.C. Bilderbeek
+#' @author Richèl J.C. Bilderbeek
 #' @examples
 #'   # Create the parameter
 #'   alpha_param <- create_alpha_param()
@@ -96,44 +94,42 @@ create_param <- function(
 #'   )
 #'
 #'   # Use the distribution to create a BEAST2 input file
+#'   beast2_input_file <- tempfile(fileext = ".xml")
 #'   create_beast2_input_file(
-#'     input_filenames = get_fasta_filename(),
-#'     "create_alpha_param.xml",
-#'     tree_priors = create_yule_tree_prior(
+#'     input_filename = get_fasta_filename(),
+#'     beast2_input_file,
+#'     tree_prior = create_yule_tree_prior(
 #'       birth_rate_distr = beta_distr
 #'     )
 #'   )
-#'   testit::assert(file.exists("create_alpha_param.xml"))
+#'   testit::assert(file.exists(beast2_input_file))
 #' @aliases create_alpha_param create_param_alpha
 #' @export create_alpha_param create_param_alpha
 create_alpha_param <- create_param_alpha <- function(
   id = NA,
-  estimate = FALSE,
   value = 0.0
 ) {
   beautier::create_param(
     name = "alpha",
     id = id,
-    estimate = estimate,
+    estimate = FALSE,
     value = value
   )
 }
 
 #' Create a parameter called beta
-#' @inheritParams create_param
-#' @param estimate TRUE if this parameter alpha be estimated by BEAST2,
-#'   FALSE otherwise
-#' @param value value of the parameter
+#' @inheritParams default_parameters_doc
 #' @return a parameter called beta
 #' @note this parameter is used in a beta distribution
 #'   (as returned by \code{\link{create_beta_distr}})
 #' and gamma distribution
 #'   (as returned by \code{\link{create_gamma_distr}})
-#' and inverse gamma distribution
-#'   (as returned by \code{\link{create_inv_gamma_distr}})
+#' and inverse-gamma distribution
+#'   (as returned by \code{\link{create_inv_gamma_distr}}).
+#' It cannot be estimated (as a hyper parameter) yet.
 #' @seealso the function \code{\link{create_param}} contains a list
 #'   of all parameters that can be created
-#' @author Richel J.C. Bilderbeek
+#' @author Richèl J.C. Bilderbeek
 #' @examples
 #'   # Create the parameter
 #'   beta_param <- create_beta_param()
@@ -144,42 +140,40 @@ create_alpha_param <- create_param_alpha <- function(
 #'   )
 #'
 #'   # Use the distribution to create a BEAST2 input file
+#'   beast2_input_file <- tempfile(fileext = ".xml")
 #'   create_beast2_input_file(
-#'     input_filenames = get_fasta_filename(),
-#'     "create_beta_param.xml",
-#'     tree_priors = create_yule_tree_prior(
+#'     input_filename = get_fasta_filename(),
+#'     beast2_input_file,
+#'     tree_prior = create_yule_tree_prior(
 #'       birth_rate_distr = gamma_distr
 #'     )
 #'   )
-#'   testit::assert(file.exists("create_beta_param.xml"))
+#'   testit::assert(file.exists(beast2_input_file))
 #' @aliases create_beta_param create_param_beta
 #' @export create_beta_param create_param_beta
 create_beta_param <- create_param_beta <- function(
   id = NA,
-  estimate = FALSE,
   value = 1.0
 ) {
   beautier::create_param(
     name = "beta",
     id = id,
-    estimate = estimate,
+    estimate = FALSE,
     value = value
   )
 }
 
 #' Create a parameter called \code{clock_rate},
 #'   as needed by \code{\link{create_strict_clock_model}}
-#' @param id the alignment id
-#' @param estimate TRUE if this parameter is estimated by BEAST2,
-#'   FALSE otherwise
-#' @param value value of the parameter
+#' @inheritParams default_parameters_doc
 #' @return a parameter called rate
+#' @note It cannot be estimated (as a hyper parameter) yet.
 #' @seealso the function \code{\link{create_param}} contains a list
 #'   of all parameters that can be created
-#' @author Richel J.C. Bilderbeek
+#' @author Richèl J.C. Bilderbeek
 #' @examples
 #'   clock_rate_param <- create_clock_rate_param(
-#'     id = "anthus_aco", estimate = FALSE, value = 1.0
+#'     id = "anthus_aco", value = 1.0
 #'   )
 #'
 #'   # Use the parameter in a clock model
@@ -188,78 +182,77 @@ create_beta_param <- create_param_beta <- function(
 #'   )
 #'
 #'   # Use the distribution to create a BEAST2 input file
+#'   beast2_input_file <- tempfile(fileext = ".xml")
 #'   create_beast2_input_file(
-#'     input_filenames = get_fasta_filename(),
-#'     "create_clock_rate_param.xml",
-#'     clock_models = strict_clock_model
+#'     input_filename = get_fasta_filename(),
+#'     beast2_input_file,
+#'     clock_model = strict_clock_model
 #'   )
-#'   testit::assert(file.exists("create_clock_rate_param.xml"))
+#'   testit::assert(file.exists(beast2_input_file))
 #' @aliases create_clock_rate_param create_param_clock_rate
 #' @export create_clock_rate_param create_param_clock_rate
 create_clock_rate_param <- create_param_clock_rate <- function(
   value = "1.0",
-  estimate = FALSE,
   id = NA
 ) {
   beautier::create_param(
     name = "clock_rate",
     id = id,
-    estimate = estimate,
+    estimate = FALSE,
     value = value
   )
 }
 
 #' Create a parameter called kappa 1
-#' @inheritParams create_param
-#' @param value value of the parameter
-#' @param lower lowest possible value of the parameter
+#' @inheritParams default_parameters_doc
 #' @return a parameter called kappa 1
-#' @author Richel J.C. Bilderbeek
+#' @author Richèl J.C. Bilderbeek
 #' @aliases create_kappa_1_param create_param_kappa_1
 #' @export create_kappa_1_param create_param_kappa_1
 create_kappa_1_param <- create_param_kappa_1 <- function(
   id = NA,
   lower = "0.0",
-  value = "2.0"
+  value = "2.0",
+  estimate = TRUE
 ) {
   beautier::create_param(
     name = "kappa_1",
     id = id,
     lower = lower,
-    value = value
+    value = value,
+    estimate = estimate
   )
 }
 
 #' Create a parameter called kappa 2
-#' @inheritParams create_param
-#' @param value value of the parameter
-#' @param lower lowest possible value of the parameter
+#' @inheritParams default_parameters_doc
 #' @return a parameter called kappa 2
-#' @author Richel J.C. Bilderbeek
+#' @author Richèl J.C. Bilderbeek
 #' @aliases create_kappa_2_param create_param_kappa_2
 #' @export create_kappa_2_param create_param_kappa_2
 create_kappa_2_param <- create_param_kappa_2 <- function(
   id = NA,
   lower = "0.0",
-  value = "2.0"
+  value = "2.0",
+  estimate = TRUE
 ) {
   beautier::create_param(
     name = "kappa_2",
     id = id,
     lower = lower,
-    value = value
+    value = value,
+    estimate = estimate
   )
 }
 
 #' Create a parameter called lambda
-#' @inheritParams create_param
-#' @param value value of the parameter
+#' @inheritParams default_parameters_doc
 #' @return a parameter called lambda
 #' @note this parameter is used in a Poisson distribution
 #'   (as returned by \code{\link{create_poisson_distr}})
 #' @seealso the function \code{\link{create_param}} contains a list
 #'   of all parameters that can be created
-#' @author Richel J.C. Bilderbeek
+#' @author Richèl J.C. Bilderbeek
 #' @examples
 #'   # Create the parameter
 #'   lambda_param <- create_lambda_param()
@@ -270,14 +263,15 @@ create_kappa_2_param <- create_param_kappa_2 <- function(
 #'   )
 #'
 #'   # Use the distribution to create a BEAST2 input file
+#'   beast2_input_file <- tempfile(fileext = ".xml")
 #'   create_beast2_input_file(
-#'     input_filenames = get_fasta_filename(),
-#'     "create_lambda_param.xml",
-#'     tree_priors = create_yule_tree_prior(
+#'     input_filename = get_fasta_filename(),
+#'     beast2_input_file,
+#'     tree_prior = create_yule_tree_prior(
 #'       birth_rate_distr = poisson_distr
 #'     )
 #'   )
-#'   testit::assert(file.exists("create_lambda_param.xml"))
+#'   testit::assert(file.exists(beast2_input_file))
 #' @aliases create_lambda_param create_param_lambda
 #' @export create_lambda_param create_param_lambda
 create_lambda_param <- create_param_lambda <- function(
@@ -292,16 +286,14 @@ create_lambda_param <- create_param_lambda <- function(
 }
 
 #' Create a parameter called m
-#' @inheritParams create_param
-#' @param estimate TRUE if this parameter alpha be estimated by BEAST2,
-#'   FALSE otherwise
-#' @param value value of the parameter
+#' @inheritParams default_parameters_doc
 #' @return a parameter called m
 #' @note this parameter is used in a log-normal distribution
 #'   (as returned by \code{\link{create_log_normal_distr}})
+#'   It cannot be estimated (as a hyper parameter) yet.
 #' @seealso the function \code{\link{create_param}} contains a list
 #'   of all parameters that can be created
-#' @author Richel J.C. Bilderbeek
+#' @author Richèl J.C. Bilderbeek
 #' @examples
 #'   # Create the parameter
 #'   m_param <- create_m_param()
@@ -312,42 +304,40 @@ create_lambda_param <- create_param_lambda <- function(
 #'   )
 #'
 #'   # Use the distribution to create a BEAST2 input file
+#'   beast2_input_file <- tempfile(fileext = ".xml")
 #'   create_beast2_input_file(
-#'     input_filenames = get_fasta_filename(),
-#'     "create_m_param.xml",
-#'     tree_priors = create_yule_tree_prior(
+#'     input_filename = get_fasta_filename(),
+#'     beast2_input_file,
+#'     tree_prior = create_yule_tree_prior(
 #'       birth_rate_distr = log_normal_distr
 #'     )
 #'   )
-#'   testit::assert(file.exists("create_m_param.xml"))
+#'   testit::assert(file.exists(beast2_input_file))
 #' @aliases create_m_param create_param_m
 #' @export create_m_param create_param_m
 create_m_param <- create_param_m <- function(
   id = NA,
-  estimate = FALSE,
   value = 0.0
 ) {
   beautier::create_param(
     name = "m",
     id = id,
-    estimate = estimate,
+    estimate = FALSE,
     value = value
   )
 }
 
 #' Create a parameter called mean
-#' @inheritParams create_param
-#' @param estimate TRUE if this parameter alpha be estimated by BEAST2,
-#'   FALSE otherwise
-#' @param value value of the parameter
+#' @inheritParams default_parameters_doc
 #' @return a parameter called mean
 #' @note this parameter is used in an exponential distribution
 #'   (as returned by \code{\link{create_exp_distr}})
-#' and normal distribution
-#'   (as returned by \code{\link{create_normal_distr}})
+#'   and normal distribution
+#'   (as returned by \code{\link{create_normal_distr}}).
+#'   It cannot be estimated (as a hyper parameter) yet.
 #' @seealso the function \code{\link{create_param}} contains a list
 #'   of all parameters that can be created
-#' @author Richel J.C. Bilderbeek
+#' @author Richèl J.C. Bilderbeek
 #' @examples
 #'   # Create the parameter
 #'   mean_param <- create_mean_param(value = 1.0)
@@ -358,40 +348,38 @@ create_m_param <- create_param_m <- function(
 #'   )
 #'
 #'   # Use the distribution to create a BEAST2 input file
+#'   beast2_input_file <- tempfile(fileext = ".xml")
 #'   create_beast2_input_file(
-#'     input_filenames = get_fasta_filename(),
-#'     "create_mean_param.xml",
-#'     tree_priors = create_yule_tree_prior(
+#'     input_filename = get_fasta_filename(),
+#'     beast2_input_file,
+#'     tree_prior = create_yule_tree_prior(
 #'       birth_rate_distr = exp_distr
 #'     )
 #'   )
-#'   testit::assert(file.exists("create_mean_param.xml"))
+#'   testit::assert(file.exists(beast2_input_file))
 #' @aliases create_mean_param create_param_mean
 #' @export create_mean_param create_param_mean
 create_mean_param <- create_param_mean <- function(
   id = NA,
-  estimate = FALSE,
   value = 0.0
 ) {
   beautier::create_param(
     name = "mean",
     id = id,
-    estimate = estimate,
+    estimate = FALSE,
     value = value
   )
 }
 
 #' Create a parameter called mu
-#' @inheritParams create_param
-#' @param estimate TRUE if this parameter mu be estimated by BEAST2,
-#'   FALSE otherwise
-#' @param value value of the parameter
+#' @inheritParams default_parameters_doc
 #' @return a parameter called mu
 #' @note this parameter is used in a Laplace distribution
-#'   (as returned by \code{\link{create_laplace_distr}})
+#'   (as returned by \code{\link{create_laplace_distr}}).
+#'   It cannot be estimated (as a hyper parameter) yet.
 #' @seealso the function \code{\link{create_param}} contains a list
 #'   of all parameters that can be created
-#' @author Richel J.C. Bilderbeek
+#' @author Richèl J.C. Bilderbeek
 #' @examples
 #'   # Create the parameter
 #'   mu_param <- create_mu_param()
@@ -402,52 +390,49 @@ create_mean_param <- create_param_mean <- function(
 #'   )
 #'
 #'   # Use the distribution to create a BEAST2 input file
+#'   beast2_input_file <- tempfile(fileext = ".xml")
 #'   create_beast2_input_file(
-#'     input_filenames = get_fasta_filename(),
-#'     "create_mu_param.xml",
-#'     tree_priors = create_yule_tree_prior(
+#'     input_filename = get_fasta_filename(),
+#'     beast2_input_file,
+#'     tree_prior = create_yule_tree_prior(
 #'       birth_rate_distr = laplace_distr
 #'     )
 #'   )
-#'   testit::assert(file.exists("create_mu_param.xml"))
+#'   testit::assert(file.exists(beast2_input_file))
 #' @aliases create_mu_param create_param_mu
 #' @export create_mu_param create_param_mu
 create_mu_param <- create_param_mu <- function(
   id = NA,
-  estimate = FALSE,
   value = 0.0
 ) {
   beautier::create_param(
     name = "mu",
     id = id,
-    estimate = estimate,
+    estimate = FALSE,
     value = value
   )
 }
 
 #' Create a parameter called 'rate AC'
-#' @inheritParams create_param
-#' @param estimate TRUE if this parameter mu be estimated by BEAST2,
-#'   FALSE otherwise
-#' @param value value of the parameter
-#' @param lower lowest possible value of the parameter
+#' @inheritParams default_parameters_doc
 #' @return a parameter called 'rate AC'
 #' @seealso the function \code{\link{create_param}} contains a list
 #'   of all parameters that can be created
-#' @author Richel J.C. Bilderbeek
+#' @author Richèl J.C. Bilderbeek
 #' @examples
 #'   # Create parameter
 #'   rate_ac_param <- create_rate_ac_param(value = 1, estimate = FALSE)
 #'
 #'   # Use the parameter to create a BEAST2 input file
+#'   beast2_input_file <- tempfile(fileext = ".xml")
 #'   create_beast2_input_file(
-#'     input_filenames = get_fasta_filename(),
-#'     "create_rate_ac_param.xml",
-#'     site_models = create_gtr_site_model(
+#'     input_filename = get_fasta_filename(),
+#'     beast2_input_file,
+#'     site_model = create_gtr_site_model(
 #'       rate_ac_param = rate_ac_param
 #'     )
 #'   )
-#'   testit::assert(file.exists("create_rate_ac_param.xml"))
+#'   testit::assert(file.exists(beast2_input_file))
 #' @aliases create_rate_ac_param create_param_rate_ac
 #' @export create_rate_ac_param create_param_rate_ac
 create_rate_ac_param <- create_param_rate_ac <- function(
@@ -466,28 +451,25 @@ create_rate_ac_param <- create_param_rate_ac <- function(
 }
 
 #' Create a parameter called 'rate AG'
-#' @inheritParams create_param
-#' @param estimate TRUE if this parameter mu be estimated by BEAST2,
-#'   FALSE otherwise
-#' @param value value of the parameter
-#' @param lower lowest possible value of the parameter
+#' @inheritParams default_parameters_doc
 #' @return a parameter called 'rate AG'
 #' @seealso the function \code{\link{create_param}} contains a list
 #'   of all parameters that can be created
-#' @author Richel J.C. Bilderbeek
+#' @author Richèl J.C. Bilderbeek
 #' @examples
 #'   # Create parameter
 #'   rate_ag_param <- create_rate_ag_param(value = 1, estimate = FALSE)
 #'
 #'   # Use the parameter to create a BEAST2 input file
+#'   beast2_input_file <- tempfile(fileext = ".xml")
 #'   create_beast2_input_file(
-#'     input_filenames = get_fasta_filename(),
-#'     "create_rate_ag_param.xml",
-#'     site_models = create_gtr_site_model(
+#'     input_filename = get_fasta_filename(),
+#'     beast2_input_file,
+#'     site_model = create_gtr_site_model(
 #'       rate_ag_param = rate_ag_param
 #'     )
 #'   )
-#'   testit::assert(file.exists("create_rate_ag_param.xml"))
+#'   testit::assert(file.exists(beast2_input_file))
 #' @aliases create_rate_ag_param create_param_rate_ag
 #' @export create_rate_ag_param create_param_rate_ag
 create_rate_ag_param <- create_param_rate_ag <- function(
@@ -506,28 +488,25 @@ create_rate_ag_param <- create_param_rate_ag <- function(
 }
 
 #' Create a parameter called 'rate AT'
-#' @inheritParams create_param
-#' @param estimate TRUE if this parameter mu be estimated by BEAST2,
-#'   FALSE otherwise
-#' @param value value of the parameter
-#' @param lower lowest possible value of the parameter
+#' @inheritParams default_parameters_doc
 #' @return a parameter called 'rate AT'
 #' @seealso the function \code{\link{create_param}} contains a list
 #'   of all parameters that can be created
-#' @author Richel J.C. Bilderbeek
+#' @author Richèl J.C. Bilderbeek
 #' @examples
 #'   # Create parameter
 #'   rate_at_param <- create_rate_at_param(value = 1, estimate = FALSE)
 #'
 #'   # Use the parameter to create a BEAST2 input file
+#'   beast2_input_file <- tempfile(fileext = ".xml")
 #'   create_beast2_input_file(
-#'     input_filenames = get_fasta_filename(),
-#'     "create_rate_at_param.xml",
-#'     site_models = create_gtr_site_model(
+#'     input_filename = get_fasta_filename(),
+#'     beast2_input_file,
+#'     site_model = create_gtr_site_model(
 #'       rate_at_param = rate_at_param
 #'     )
 #'   )
-#'   testit::assert(file.exists("create_rate_at_param.xml"))
+#'   testit::assert(file.exists(beast2_input_file))
 #' @aliases create_rate_at_param create_param_rate_at
 #' @export create_rate_at_param create_param_rate_at
 create_rate_at_param <- create_param_rate_at <- function(
@@ -546,28 +525,25 @@ create_rate_at_param <- create_param_rate_at <- function(
 }
 
 #' Create a parameter called 'rate CG'
-#' @inheritParams create_param
-#' @param estimate TRUE if this parameter mu be estimated by BEAST2,
-#'   FALSE otherwise
-#' @param value value of the parameter
-#' @param lower lowest possible value of the parameter
+#' @inheritParams default_parameters_doc
 #' @return a parameter called 'rate CG'
 #' @seealso the function \code{\link{create_param}} contains a list
 #'   of all parameters that can be created
-#' @author Richel J.C. Bilderbeek
+#' @author Richèl J.C. Bilderbeek
 #' @examples
 #'   # Create parameter
 #'   rate_cg_param <- create_rate_cg_param(value = 1, estimate = FALSE)
 #'
 #'   # Use the parameter to create a BEAST2 input file
+#'   beast2_input_file <- tempfile(fileext = ".xml")
 #'   create_beast2_input_file(
-#'     input_filenames = get_fasta_filename(),
-#'     "create_rate_cg_param.xml",
-#'     site_models = create_gtr_site_model(
+#'     input_filename = get_fasta_filename(),
+#'     beast2_input_file,
+#'     site_model = create_gtr_site_model(
 #'       rate_cg_param = rate_cg_param
 #'     )
 #'   )
-#'   testit::assert(file.exists("create_rate_cg_param.xml"))
+#'   testit::assert(file.exists(beast2_input_file))
 #' @aliases create_rate_cg_param create_param_rate_cg
 #' @export create_rate_cg_param create_param_rate_cg
 create_rate_cg_param <- create_param_rate_cg <- function(
@@ -586,68 +562,61 @@ create_rate_cg_param <- create_param_rate_cg <- function(
 }
 
 #' Create a parameter called 'rate CT'
-#' @inheritParams create_param
-#' @param estimate TRUE if this parameter mu be estimated by BEAST2,
-#'   FALSE otherwise
-#' @param value value of the parameter
-#' @param lower lowest possible value of the parameter
+#' @inheritParams default_parameters_doc
 #' @return a parameter called 'rate CT'
 #' @seealso the function \code{\link{create_param}} contains a list
 #'   of all parameters that can be created
-#' @author Richel J.C. Bilderbeek
+#' @author Richèl J.C. Bilderbeek
 #' @examples
 #'   # Create parameter
-#'   rate_ct_param <- create_rate_ct_param(value = 1, estimate = FALSE)
+#'   rate_ct_param <- create_rate_ct_param(value = 1)
 #'
 #'   # Use the parameter to create a BEAST2 input file
+#'   beast2_input_file <- tempfile(fileext = ".xml")
 #'   create_beast2_input_file(
-#'     input_filenames = get_fasta_filename(),
-#'     "create_rate_ct_param.xml",
-#'     site_models = create_gtr_site_model(
+#'     input_filename = get_fasta_filename(),
+#'     beast2_input_file,
+#'     site_model = create_gtr_site_model(
 #'       rate_ct_param = rate_ct_param
 #'     )
 #'   )
-#'   testit::assert(file.exists("create_rate_ct_param.xml"))
+#'   testit::assert(file.exists(beast2_input_file))
 #' @aliases create_rate_ct_param create_param_rate_ct
 #' @export create_rate_ct_param create_param_rate_ct
 create_rate_ct_param <- create_param_rate_ct <- function(
   id = NA,
-  estimate = TRUE,
   value = "1.0",
   lower = "0.0"
 ) {
   beautier::create_param(
     name = "rate_ct",
     id = id,
-    estimate = estimate,
+    estimate = FALSE,
     value = value,
     lower = lower
   )
 }
 
 #' Create a parameter called 'rate GT'
-#' @inheritParams create_param
-#' @param estimate TRUE if this parameter mu be estimated by BEAST2,
-#'   FALSE otherwise
-#' @param value value of the parameter
-#' @param lower lowest possible value of the parameter
+#' @inheritParams default_parameters_doc
 #' @return a parameter called 'rate GT'
 #' @seealso the function \code{\link{create_param}} contains a list
 #'   of all parameters that can be created
-#' @author Richel J.C. Bilderbeek
+#' @author Richèl J.C. Bilderbeek
 #' @examples
 #'   # Create parameter
 #'   rate_gt_param <- create_rate_gt_param(value = 1, estimate = FALSE)
 #'
 #'   # Use the parameter to create a BEAST2 input file
+#'   beast2_input_file <- tempfile(fileext = ".xml")
 #'   create_beast2_input_file(
-#'     input_filenames = get_fasta_filename(),
-#'     "create_rate_gt_param.xml",
-#'     site_models = create_gtr_site_model(
+#'     input_filename = get_fasta_filename(),
+#'     beast2_input_file,
+#'     site_model = create_gtr_site_model(
 #'       rate_gt_param = rate_gt_param
 #'     )
 #'   )
-#'   testit::assert(file.exists("create_rate_gt_param.xml"))
+#'   testit::assert(file.exists(beast2_input_file))
 #' @aliases create_rate_gt_param create_param_rate_gt
 #' @export create_rate_gt_param create_param_rate_gt
 create_rate_gt_param <- create_param_rate_gt <- function(
@@ -666,18 +635,13 @@ create_rate_gt_param <- create_param_rate_gt <- function(
 }
 
 #' Create a parameter called s
-#' @inheritParams create_param
-#' @param estimate TRUE if this parameter alpha be estimated by BEAST2,
-#'   FALSE otherwise
-#' @param value value of the parameter
-#' @param lower lower value of the parameter
-#' @param upper upper value of the parameter
+#' @inheritParams default_parameters_doc
 #' @return a parameter called s
 #' @note this parameter is used in a log-normal distribution
 #'   (as returned by \code{\link{create_log_normal_distr}})
 #' @seealso the function \code{\link{create_param}} contains a list
 #'   of all parameters that can be created
-#' @author Richel J.C. Bilderbeek
+#' @author Richèl J.C. Bilderbeek
 #' @examples
 #'   # Create the parameter
 #'   s_param <- create_s_param()
@@ -688,27 +652,27 @@ create_rate_gt_param <- create_param_rate_gt <- function(
 #'   )
 #'
 #'   # Use the distribution to create a BEAST2 input file
+#'   beast2_input_file <- tempfile(fileext = ".xml")
 #'   create_beast2_input_file(
-#'     input_filenames = get_fasta_filename(),
-#'     "create_s_param.xml",
-#'     tree_priors = create_yule_tree_prior(
+#'     input_filename = get_fasta_filename(),
+#'     beast2_input_file,
+#'     tree_prior = create_yule_tree_prior(
 #'       birth_rate_distr = log_normal_distr
 #'     )
 #'   )
-#'   testit::assert(file.exists("create_s_param.xml"))
+#'   testit::assert(file.exists(beast2_input_file))
 #' @aliases create_s_param create_param_s
 #' @export create_s_param create_param_s
 create_s_param <- create_param_s <- function(
   id = NA,
-  estimate = FALSE,
   value = 0.0,
   lower = 0.0,
-  upper = 0.0
+  upper = Inf
 ) {
   beautier::create_param(
     name = "s",
     id = id,
-    estimate = estimate,
+    estimate = FALSE,
     value = value,
     lower = lower,
     upper = upper
@@ -716,16 +680,14 @@ create_s_param <- create_param_s <- function(
 }
 
 #' Create a parameter called scale
-#' @inheritParams create_param
-#' @param estimate TRUE if this parameter scale be estimated by BEAST2,
-#'   FALSE otherwise
+#' @inheritParams default_parameters_doc
 #' @param value value of the parameter
 #' @return a parameter called scale
 #' @note this parameter is used in a Laplace distribution
 #'   (as returned by \code{\link{create_laplace_distr}})
 #' @seealso the function \code{\link{create_param}} contains a list
 #'   of all parameters that can be created
-#' @author Richel J.C. Bilderbeek
+#' @author Richèl J.C. Bilderbeek
 #' @examples
 #'   # Create the parameter
 #'   scale_param <- create_scale_param()
@@ -736,40 +698,38 @@ create_s_param <- create_param_s <- function(
 #'   )
 #'
 #'   # Use the distribution to create a BEAST2 input file
+#'   beast2_input_file <- tempfile(fileext = ".xml")
 #'   create_beast2_input_file(
-#'     input_filenames = get_fasta_filename(),
-#'     "create_scale_param.xml",
-#'     tree_priors = create_yule_tree_prior(
+#'     input_filename = get_fasta_filename(),
+#'     beast2_input_file,
+#'     tree_prior = create_yule_tree_prior(
 #'       birth_rate_distr = laplace_distr
 #'     )
 #'   )
-#'   testit::assert(file.exists("create_scale_param.xml"))
+#'   testit::assert(file.exists(beast2_input_file))
 #' @aliases create_scale_param create_param_scale
 #' @export create_scale_param create_param_scale
 create_scale_param <- create_param_scale <- function(
   id = NA,
-  estimate = FALSE,
   value = 0.0
 ) {
   beautier::create_param(
     name = "scale",
     id = id,
-    estimate = estimate,
+    estimate = FALSE,
     value = value
   )
 }
 
 #' Create a parameter called sigma
-#' @inheritParams create_param
-#' @param estimate TRUE if this parameter alpha be estimated by BEAST2,
-#'   FALSE otherwise
+#' @inheritParams default_parameters_doc
 #' @param value value of the parameter
 #' @return a parameter called sigma
 #' @note this parameter is used in a normal distribution
 #'   (as returned by \code{\link{create_normal_distr}})
 #' @seealso the function \code{\link{create_param}} contains a list
 #'   of all parameters that can be created
-#' @author Richel J.C. Bilderbeek
+#' @author Richèl J.C. Bilderbeek
 #' @examples
 #'   # Create the parameter
 #'   sigma_param <- create_sigma_param()
@@ -780,19 +740,19 @@ create_scale_param <- create_param_scale <- function(
 #'   )
 #'
 #'   # Use the distribution to create a BEAST2 input file
+#'   beast2_input_file <- tempfile(fileext = ".xml")
 #'   create_beast2_input_file(
-#'     input_filenames = get_fasta_filename(),
-#'     "create_sigma_param.xml",
-#'     tree_priors = create_yule_tree_prior(
+#'     input_filename = get_fasta_filename(),
+#'     beast2_input_file,
+#'     tree_prior = create_yule_tree_prior(
 #'       birth_rate_distr = normal_distr
 #'     )
 #'   )
-#'   testit::assert(file.exists("create_sigma_param.xml"))
+#'   testit::assert(file.exists(beast2_input_file))
 #' @aliases create_sigma_param create_param_sigma
 #' @export create_sigma_param create_param_sigma
 create_sigma_param <- create_param_sigma <- function(
   id = NA,
-  estimate = FALSE,
   value = 1.0
 ) {
   if (value <= 0.0) {
@@ -801,7 +761,7 @@ create_sigma_param <- create_param_sigma <- function(
   beautier::create_param(
     name = "sigma",
     id = id,
-    estimate = estimate,
+    estimate = FALSE,
     value = value
   )
 }
