@@ -1,13 +1,14 @@
 #' Indent text for a certain number of spaces.
 #' If the text is only whitespace, leave it as such
 #' @param text the text to indent
-#' @param n_spaces the number of spaces to add before the text
+#' @param n_spaces the number of spaces to add before the text. BEAUti uses
+#'   four spaces by default
 #' @return the indented text
 #' @author Richèl J.C. Bilderbeek
-#' @noRd
+#' @export
 indent <- function(
   text,
-  n_spaces
+  n_spaces = 4
 ) {
   if (n_spaces < 0) {
     stop("'n_spaces' must be a positive integer")
