@@ -2,13 +2,13 @@
 #' @param lines lines of text
 #' @return interspaced lines of text
 #' @author Richèl J.C. Bilderbeek
-#' @noRd
+#' @export
 interspace <- function(lines) {
 
   if (length(lines) == 0) return(lines)
 
   # number of spaces of non-indented line
-  nsni <- count_trailing_spaces(lines[1]) # nolint beautier function
+  nsni <- beautier::count_trailing_spaces(lines[1])
 
   result <- NULL
   for (i in seq_along(lines)) {
@@ -19,8 +19,8 @@ interspace <- function(lines) {
     # - this line is indented
     # - the next line is indented
     if (i == length(lines)) next
-    if (count_trailing_spaces(line) == nsni
-      && count_trailing_spaces(lines[i + 1]) == nsni
+    if (beautier::count_trailing_spaces(line) == nsni
+      && beautier::count_trailing_spaces(lines[i + 1]) == nsni
     ) {
       result <- c(result, "")
     }
