@@ -8,8 +8,8 @@
 #' #'   # Here
 #' # </logger>
 #' @author Richèl J.C. Bilderbeek
-#' @noRd
-mrca_prior_to_xml_tracelog <- function( # nolint beautier function
+#' @export
+mrca_prior_to_xml_tracelog <- function(
   clock_models,
   mrca_prior,
   tipdates_filename = NA
